@@ -11,7 +11,7 @@ try:
     from executorlib.interactive.flux import FluxPythonSpawner
 
     skip_flux_test = "FLUX_URI" not in os.environ
-    pmi = os.environ.get("PYMPIPOOL_PMIX", None)
+    pmi = os.environ.get("EXECUTORLIB_PMIX", None)
 except ImportError:
     skip_flux_test = True
 
